<?php
/**
 * Module to display any information stored in Joomla!/WordPress database
 * 
 * @category   Custom
 * @package    DWAnything
 * @author     Ilya Vikharev {@link http://factory.docwriter.ru}
 * @copyright  2017 DocWriter.Ru
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version    4.01.0004 $Id: dwanything.php 1576930 2017-01-18 01:16:47Z dwfactory $
 * @link       http://factory.docwriter.ru
 * @since      File available since Release 4.00
 */
 
//--No direct access
defined('ABSPATH') or defined('_JEXEC') or die('Direct access to this location is not allowed.');

class DWAnythingWidget extends WP_Widget {
    
    private $_controller;
    
    public function __construct() {
        
        $params =  array(
            'description' => __('Display DW Anything-rendered layout.', 'dw-anything')
                . ' '
                . __('Click Help for details.', 'dw-anything'),
            'name' => __('DW Anything Widget', 'dw-anything')
        );
        
        $this->_controller = DWAnythingController::getInstance();
        
        add_action('load-widgets.php', array($this, 'addHelpTab'));
        
        parent::__construct('DWAnythingWidget', '', $params);
    }
    
    public function addHelpTab() {
        
        if (is_object($scr = get_current_screen())) {
            
            // Help
            $helpTabs = array(
                'dwa_widget_help' => array(
                    'id' => 'dwa_widget_help',
                    'title' => __('DW Anything Options', 'dw-anything'),
                    'content' =>
                        '<dl>'
                        . '<dt>'
                        . __('Title', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('Enter title for your widget.', 'dw-anything')
                        . '</dd>'
                        . '<dt>'
                        . __('SQL Query', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('Get rows from your database.', 'dw-anything')
                        . '</dd>'
                        . '<dt>'
                        . __('Header HTML', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('The header is displayed in your widget before a main template.', 'dw-anything')
                        . '</dd>'
                        . '<dt>'
                        . __('Template', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('The main template is rendered as many times as there are rows returned by the SQL Query. The template is populated with data from each row. Place the desired column names anywhere within the template where you need the data to be inserted surrounding them in curly brackets, e.g. <tt>{comment_content}</tt>', 'dw-anything')
                        . '</dd>'
                        . '<dt>'
                        . __('Footer HTML', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('The footer is displayed in your widget after a main template.', 'dw-anything')
                        . '</dd>'
                        . '</dl>'
                    
                ),
                'dwa_widget_primer' => array(
                    'id' => 'dwa_widget_primer',
                    'title' => __('DW Anything Primer', 'dw-anything'),
                    'content' =>
                        '<p>'
                        . __('Build a widget with the latest comments from current user.', 'dw-anything')
                        . '</p>'
                        . '<dl>'
                        . '<dt>'
                        . __('Title', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . __('<tt>Latest Comments by {user.display_name}</tt>', 'dw-anything')
                        . '</dd>'
                        . '<dt>'
                        . __('SQL Query', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . '<tt>SELECT * FROM {table.comments} WHERE user_id = \'{user.ID}\' ORDER BY comment_ID DESC</tt>'
                        . '</dd>'
                        . '<dt>'
                        . __('Header HTML', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . '<tt>&lt;ul&gt;</tt>'
                        . '</dd>'
                        . '<dt>'
                        . __('Template', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . '<tt>&lt;li&gt;{comment_content}&lt;/li&gt;</tt>'
                        . '</dd>'
                        . '<dt>'
                        . __('Footer HTML', 'dw-anything')
                        . '</dt>'
                        . '<dd>'
                        . '<tt>&lt;/ul&gt;</tt>'
                        . '</dd>'
                        . '</dl>'
                    
                )
            );
            foreach ($helpTabs as $curTab) {
                $scr->add_help_tab($curTab);
            }
        }
    }
    
    public function form($instance) {
        
        extract($instance);
        
        ?>
        <p>
            <label for="<?php echo($this->get_field_id('title')); ?>"><?php echo __('Title', 'dw-anything'); ?>:</label>
            <input
                type="text"
                class="widefat"
                id="<?php echo($this->get_field_id('title')); ?>"
                name="<?php echo($this->get_field_name('title')); ?>"
                value="<?php if (isset($title)) echo(esc_attr($title)) ?>" />
        </p>
        <p>
            <label for="<?php echo($this->get_field_id('query')); ?>"><?php echo __('SQL query', 'dw-anything'); ?>:</label>
            <textarea
                class="widefat"
                id="<?php echo($this->get_field_id('query')); ?>"
                name="<?php echo($this->get_field_name('query')); ?>"><?php if (isset($query)) echo(esc_attr($query)) ?></textarea>
        </p>
        <p>
            <label for="<?php echo($this->get_field_id('header')); ?>"><?php echo __('Header HTML', 'dw-anything'); ?>:</label>
            <textarea
                class="widefat"
                id="<?php echo($this->get_field_id('header')); ?>"
                name="<?php echo($this->get_field_name('header')); ?>"><?php if (isset($header)) echo(esc_attr($header)) ?></textarea>
        </p>
        <p>
            <label for="<?php echo($this->get_field_id('template')); ?>"><?php echo __('Template', 'dw-anything'); ?>:</label>
            <textarea
                class="widefat"
                id="<?php echo($this->get_field_id('template')); ?>"
                name="<?php echo($this->get_field_name('template')); ?>"><?php if (isset($template)) echo(esc_attr($template)) ?></textarea>
        </p>
        <p>
            <label for="<?php echo($this->get_field_id('footer')); ?>"><?php echo __('Footer HTML', 'dw-anything'); ?>:</label>
            <textarea
                class="widefat"
                id="<?php echo($this->get_field_id('footer')); ?>"
                name="<?php echo($this->get_field_name('footer')); ?>"><?php if (isset($footer)) echo(esc_attr($footer)) ?></textarea>
        </p>
        <?php
    }
    
    public function widget($args, $instance) {
        
        //extract($args);
        //extract($instance);
        //
        //$title = apply_filters('widget_title', $title);
        
        global $wpdb;
        $query = $instance['query'];
        $query = DWAnythingHelperWP::renderDataSources($query);

        $items = DWAnythingHelperWP::getItems($query);
        
        $view = $this->_controller->getView();
        
        echo($args['before_widget']);
            if (isset($instance['title'])) echo($args['before_title'] . apply_filters('widget_title', DWAnythingHelperWP::renderDataSources($instance['title'])) . $args['after_title']);
            if (isset($instance['header'])) echo(DWAnythingHelperWP::renderDataSources($instance['header']));
            if (isset($instance['template'])) {
                foreach ($items as $curRow) {
                    echo(DWAnythingHelperWP::renderRow($instance['template'], $curRow));
                }
            }
            if (isset($instance['footer'])) echo(DWAnythingHelperWP::renderDataSources($instance['footer']));
        echo($args['after_widget']);
        
    }
}
