<?php
/**
 * Module to display any information stored in Joomla!/WordPress database
 * 
 * @category   Custom
 * @package    DWAnything
 * @author     Ilya Vikharev {@link http://factory.docwriter.ru}
 * @copyright  2017 DocWriter.Ru
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version    4.00.0001 $Id: controller.php 1576930 2017-01-18 01:16:47Z dwfactory $
 * @link       http://factory.docwriter.ru
 * @since      File available since Release 4.00
 */
 
//--No direct access
defined('ABSPATH') or die('Direct access to this location is not allowed.');

class DWAnythingController {
    
    private $classPrefix = 'DWAnything';
    
    public function __construct()
	{
        add_action('widgets_init', array($this, 'widgets_init'));
	}
    
    /**
     * Load class by path (don notation).
     *
     * @param string $path Class path in dot notation.
     * @return string
     */
    private static function loadClass ($path) {
    
        $result = null;
    
        $filePath = dirname(__FILE__) . '/classes/' . str_replace('.', '/', $path) . '.php';
        if (file_exists($filePath)) {
            require_once($filePath);
        }
    
        return $result;
    } // End function loadClass()
    
    /**
     * Get the view object.
     *
     * @param string $name View name to load.
     * @return object
     */
    public function getView ($name = 'default') {
        
        require_once("views/" . strtolower($name) . ".php");
        
        $className = $this->classPrefix . ucfirst($name) . 'View';
        $result = $className::getInstance();
        
        return $result;
    }

	/**
	 * callback for the 'widgets_init' action
	 *
	 * In this function, we determine what WordPress is doing and add plugin actions depending upon the results.
	 * This helps to keep the plugin code as light as possible, and reduce processing times.
	 *
	 * @package DW Anything
	 *
	 * @since 4.00
	 */
	public function widgets_init()
	{
        $this->loadClass('widgets.dwanything');
        register_widget('DWAnythingWidget');
	}

	/**
	 * callback for the 'init' action
	 *
	 * In this function, we determine what WordPress is doing and add plugin actions depending upon the results.
	 * This helps to keep the plugin code as light as possible, and reduce processing times.
	 *
	 * @package DW Anything
	 *
	 * @since 4.00
	 */
	public function init()
	{
		////is this a post display page? If so, then filter the content\
		//if(is_single())
		//	add_filter('the_content', array(&$this, 'render_single_post'));
	}

    public static function & getInstance () {
        
        static $result;
        
        if (!isset($result)) {
            $result = new static();
        }
        
        return $result;
    }
}