<?php
/**
 * Module to display any information stored in Joomla!/WordPress database
 * 
 * @category   Custom
 * @package    DWAnything
 * @author     Ilya Vikharev {@link http://factory.docwriter.ru}
 * @copyright  2009-2017 DocWriter.Ru
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version    4.00.0005.1 $Id: helper.php 1576930 2017-01-18 01:16:47Z dwfactory $
 * @link       http://factory.docwriter.ru
 * @since      File available since Release 1.00
 */
 
//--No direct access
defined('ABSPATH') or defined('_JEXEC') or die('Direct access to this location is not allowed.');

/**
 * WordPress-specific methods
 */
class DWAnythingHelperWP extends ModDWAnythingHelper {
    
    /**
     * Returns a list of data rows
     *
     * @param string $query SQL_QUERY to get params from database
     */
    public static function getItems($query) {
        
        // Initialize variables
        global $wpdb;
        $result = null;
        
        $result = ($result = $wpdb->get_results($query)) ? $result : array();
        
        return $result;
    } //end getItems
}


/**
 * Helper class for DWAnything
 */
class ModDWAnythingHelper
{
    
    /**
     * Read the files in a folder.
     *
	 * @param   string   $path           The path of the folder to read.
	 * @param   string   $filter         A filter for file names.
	 * @param   mixed    $recurse        True to recursively search into sub-folders, or an integer to specify the maximum depth.
	 * @param   boolean  $full           True to return the full path to the file.
	 * @param   array    $exclude        Array with names of files which should not be shown in the result.
	 * @param   array    $excludefilter  Array of filter to exclude
	 * @param   boolean  $naturalSort    False for asort, true for natsort
	 *
	 * @return  array  Files in the given folder.
	 *
     * @return boolean
     */
    protected static function _folderFiles ($path, $filter = '.', $recurse = false, $full = false, $exclude = array()) {
    
        $result = false;
    
        jimport('joomla.filesystem.folder');
        
        $result = JFolder::files($path, $filter, $recurse, $full, $exclude);
    
        return $result;
    } // End function _folderExists()
    
    /**
     * Check if the folder exists.
     *
     * @param string $path Folder name relative to installation dir
     *
     * @return boolean
     */
    protected static function _folderExists ($path) {
    
        $result = false;
    
        jimport('joomla.filesystem.folder');
        
        $result = JFolder::exists($path);
    
        return $result;
    } // End function _folderExists()
    
    protected static function & _mapDataSource ($file, $path, &$data) {
        
        JLoader::import('joomla.filesystem.file');
        
        $name = JFile::stripExt($file);

        $source = self::_getDataSource($file, $path);
        if (is_object($source)) {
            $sourceData = $source->getData();
            if (is_array($sourceData)) {
                foreach ($sourceData as $curKey => $curValue) {
                    $data->set("$name.$curKey", $curValue);
                }
            }
        }
        
        return $data;
    }
    
    protected static function _getDataSource ($file, $path) {
        
        JLoader::import('joomla.filesystem.file');
        
        $result = null;
        
        $name = JFile::stripExt($file);
        $class = 'DWAnythingDataSource' . ucfirst($name);
        if (!class_exists($class)) {
            JLoader::import($name, $path);
        }
        if (class_exists($class)) {
            $result = new $class ();
        }
        
        return $result;
    }
    
    /**
     * Load external data sources.
     *
     * Data source classes are located in 'classes/datasources' sub-directory of DW
     * Anythng installation directory.
     * 
     * @return JObject data from data sources
     */
    public static function &getDataSources () {
        
        static $result = null;
        
        if (is_null($result)) {
            $path = dirname(__FILE__) . '/classes/datasources';
            $filter = '.*\.php';
            
            $result = new JObject();
            if (self::_folderExists($path)) {
                foreach(self::_folderFiles($path, $filter) as $curFile) {
                    $result = self::_mapDataSource($curFile, $path, $result);
                }
            }
        }
        
        return $result;
    }
    
    
    /**
     * Replace template fields with actual values from data row and render data
     * sources.
     * 
     * @param string $template template source text
     * @param object $row data object
     * 
     * @return string Populated template
     */
    public static function renderRow ($template, &$row) {
        
        $result = $template;
        
        $result = self::parseTemplate($result, $row);
        $result = self::renderDataSources($result);
        
        return $result;
    }
    
    /**
     * Returns a list of data rows
     *
     * @param string $query SQL_QUERY to get params from database
     */
    public static function getItems($query) {
        
        // Initialize variables
        $result = null;
        
        // Get a reference to the database
        $db = JFactory::getDBO();
 
        // Get a list of items
        $db->setQuery($query);
        $result = ($result = $db->loadObjectList()) ? $result : array();
        
        return $result;
    } //end getItems
    
    /**
     * Replace template fields with actual values from data sources.
     * 
     * @param string $template template source text
     * 
     * @return string Populated template
     */
    public static function renderDataSources ($template) {
        
        $result = '';
        
        $result = self::parseTemplate($template, self::getDataSources());
        
        return $result;
    }
    
    /**
     * Replace template fields with actual values.
     * 
     * @param string $template template source text
     * @param object $row data object
     * 
     * @return string Populated template
     */
    public static function parseTemplate ($template, &$row) {
        
        $result = '';
        
        $result = $template;
        
        $vars = get_object_vars($row);
        
        foreach ($vars as $curKey => $curValue) {
            if (is_string($curKey) and is_scalar($curValue)
                or is_null($curValue)) { // NULL required to represent empty values
                $result = str_replace('{' . $curKey . '}', $curValue, $result);
            }
        }
        
        return $result;        
    }
 
} //end ModDWAnythingHelper